create.panda.style.RdThis function is able to create a Cytoscape visual style for any PANDA network output.
create.panda.style(style_name = "PandaStyle")
| style_name | Character string indicating the style name. Defaults to "PandaStyle" |
|---|
A visual style in Cytoscape Control Panel under "Style" button.